@@ -16,9 +16,10 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
 """A library that provides a Python interface to the Telegram Bot API"""
 
+from sys import version_info
+
 from .base import TelegramObject
 from .user import User
 from .chat import Chat
@@ -79,66 +80,26 @@ from .inputcontactmessagecontent import InputContactMessageContent
 from .update import Update
 from .bot import Bot
 
-
 __author__ = 'devs@python-telegram-bot.org'
-__version__ = '4.0.2'
-__all__ = ['Audio',
-           'Bot',
-           'Chat',
-           'ChatAction',
-           'ChosenInlineResult',
-           'CallbackQuery',
-           'Contact',
-           'Document',
-           'Emoji',
-           'File',
-           'ForceReply',
-           'InlineKeyboardButton',
-           'InlineKeyboardMarkup',
-           'InlineQuery',
-           'InlineQueryResult',
-           'InlineQueryResult',
-           'InlineQueryResultArticle',
-           'InlineQueryResultAudio',
-           'InlineQueryResultCachedAudio',
-           'InlineQueryResultCachedDocument',
-           'InlineQueryResultCachedGif',
-           'InlineQueryResultCachedMpeg4Gif',
-           'InlineQueryResultCachedPhoto',
-           'InlineQueryResultCachedSticker',
-           'InlineQueryResultCachedVideo',
-           'InlineQueryResultCachedVoice',
-           'InlineQueryResultContact',
-           'InlineQueryResultDocument',
-           'InlineQueryResultGif',
-           'InlineQueryResultLocation',
-           'InlineQueryResultMpeg4Gif',
-           'InlineQueryResultPhoto',
-           'InlineQueryResultVenue',
-           'InlineQueryResultVideo',
-           'InlineQueryResultVoice',
-           'InputContactMessageContent',
-           'InputFile',
-           'InputLocationMessageContent',
-           'InputMessageContent',
-           'InputTextMessageContent',
-           'InputVenueMessageContent',
-           'KeyboardButton',
-           'Location',
-           'Message',
-           'MessageEntity',
-           'NullHandler',
-           'ParseMode',
-           'PhotoSize',
-           'ReplyKeyboardHide',
-           'ReplyKeyboardMarkup',
-           'ReplyMarkup',
-           'Sticker',
-           'TelegramError',
-           'TelegramObject',
-           'Update',
-           'User',
-           'UserProfilePhotos',
-           'Venue',
-           'Video',
-           'Voice']
+__version__ = '4.1.1'
+__all__ = ['Audio', 'Bot', 'Chat', 'ChatAction', 'ChosenInlineResult', 'CallbackQuery', 'Contact',
+           'Document', 'Emoji', 'File', 'ForceReply', 'InlineKeyboardButton',
+           'InlineKeyboardMarkup', 'InlineQuery', 'InlineQueryResult', 'InlineQueryResult',
+           'InlineQueryResultArticle', 'InlineQueryResultAudio', 'InlineQueryResultCachedAudio',
+           'InlineQueryResultCachedDocument', 'InlineQueryResultCachedGif',
+           'InlineQueryResultCachedMpeg4Gif', 'InlineQueryResultCachedPhoto',
+           'InlineQueryResultCachedSticker', 'InlineQueryResultCachedVideo',
+           'InlineQueryResultCachedVoice', 'InlineQueryResultContact', 'InlineQueryResultDocument',
+           'InlineQueryResultGif', 'InlineQueryResultLocation', 'InlineQueryResultMpeg4Gif',
+           'InlineQueryResultPhoto', 'InlineQueryResultVenue', 'InlineQueryResultVideo',
+           'InlineQueryResultVoice', 'InputContactMessageContent', 'InputFile',
+           'InputLocationMessageContent', 'InputMessageContent', 'InputTextMessageContent',
+           'InputVenueMessageContent', 'KeyboardButton', 'Location', 'Message', 'MessageEntity',
+           'NullHandler', 'ParseMode', 'PhotoSize', 'ReplyKeyboardHide', 'ReplyKeyboardMarkup',
+           'ReplyMarkup', 'Sticker', 'TelegramError', 'TelegramObject', 'Update', 'User',
+           'UserProfilePhotos', 'Venue', 'Video', 'Voice']
+
+if version_info < (2, 7):
+    from warnings import warn
+    warn("python-telegram-bot will stop supporting Python 2.6 in a future release. "
+         "Please upgrade your Python!")
